summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/notes.h
diff options
context:
space:
mode:
authorAdam Borowski <kilobyte@angband.pl>2012-02-20 05:07:00 +0100
committerAdam Borowski <kilobyte@angband.pl>2012-02-20 05:07:00 +0100
commit30d37ef7a7daa2b88f93d43bccb9c141448edf65 (patch)
treed24da09d0c51b53cbd1e8507a252af5a8f61a841 /crawl-ref/source/notes.h
parentb89be0430b6359a069e13c86565dbf6985eefe5e (diff)
parent9d196e98bf78ac3589ad650da44d0b9a2d6613a2 (diff)
downloadcrawl-ref-30d37ef7a7daa2b88f93d43bccb9c141448edf65.tar.gz
crawl-ref-30d37ef7a7daa2b88f93d43bccb9c141448edf65.zip
Merge branch 'master' into portal_branches
Diffstat (limited to 'crawl-ref/source/notes.h')
-rw-r--r--crawl-ref/source/notes.h3
1 files changed, 1 insertions, 2 deletions
diff --git a/crawl-ref/source/notes.h b/crawl-ref/source/notes.h
index cfd8f98ead..2d0515e485 100644
--- a/crawl-ref/source/notes.h
+++ b/crawl-ref/source/notes.h
@@ -34,7 +34,7 @@ enum NOTE_TYPES
NOTE_GAIN_SKILL, /* needs: skill id, level */
NOTE_LOSE_SKILL, /* needs: skill id, level */
NOTE_SEEN_MONSTER, /* needs: monster name (string) */
- NOTE_KILL_MONSTER, /* needs: monster name (string) */
+ NOTE_DEFEAT_MONSTER, /* needs: monster name, defeat verb (strings) */
NOTE_POLY_MONSTER, /* needs: monster name (string) */
NOTE_USER_NOTE, /* needs: description string */
NOTE_MESSAGE, /* needs: message string */
@@ -50,7 +50,6 @@ enum NOTE_TYPES
NOTE_PARALYSIS, /* needs: paralysis source (string) */
NOTE_NAMED_ALLY, /* needs: ally name (string) */
NOTE_ALLY_DEATH, /* needs: ally name (string) */
- NOTE_BANISH_MONSTER, /* needs: monster name (string) */
NOTE_FEAT_MIMIC, /* needs: mimiced feature (string) */
NOTE_NUM_TYPES
};